@@ -189,5 +189,5 @@ print.coxreg <-
     if (length(x$icc))
 	cat("   number of clusters=", x$icc[1],
 	    "    ICC=", format(x$icc[2:3]), "\n")
-    invisible()
+    invisible(x)
 }
